@@ -2,7 +2,7 @@ use strict;
 use warnings;
 use 5.014;
 
-package App::af 0.03 {
+package App::af 0.04 {
 
   use Moose::Role;
   use namespace::autoclean;
@@ -45,7 +45,16 @@ package App::af 0.03 {
       $name =~ s/_/-/g;
       $name .= '|' . $attr->short    if $attr->short;
       $name .= "=" . $attr->opt_type if $attr->opt_type;
-      push @options, $name => \$args{$attr->name};
+      if($attr->opt_type =~ /\{/)
+      {
+        my @array;
+        $args{$attr->name} = \@array;
+        push @options, $name => \@array;
+      }
+      else
+      {
+        push @options, $name => \$args{$attr->name};
+      }
     }
     
     GetOptionsFromArray(\@args, @options)
@@ -114,14 +123,13 @@ package App::af::role::alienfile {
   
   sub build
   {
-    my($self) = @_;
+    my($self, %args) = @_;
     
     my $alienfile;
     
-    my %args;
     my $prefix;
     
-    $args{root} = tempdir( CLEANUP => 1);
+    $args{root} ||= tempdir( CLEANUP => 1);
     
     if($self->class)
     {
@@ -220,7 +228,7 @@ App::af - Command line tool for alienfile
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
